@@ -1,7 +1,8 @@
 from .inference import (inference_bottom_up_pose_model,
                         inference_top_down_pose_model, init_pose_model,
                         vis_pose_result)
-from .inference_3d import inference_pose_lifter_model, vis_3d_pose_result
+from .inference_3d import (extract_pose_sequence, inference_interhand_3d_model,
+                           inference_pose_lifter_model, vis_3d_pose_result)
 from .inference_tracking import get_track_id, vis_pose_tracking_result
 from .test import multi_gpu_test, single_gpu_test
 from .train import train_model
@@ -10,5 +11,6 @@ __all__ = [
     'train_model', 'init_pose_model', 'inference_top_down_pose_model',
     'inference_bottom_up_pose_model', 'multi_gpu_test', 'single_gpu_test',
     'vis_pose_result', 'get_track_id', 'vis_pose_tracking_result',
-    'inference_pose_lifter_model', 'vis_3d_pose_result'
+    'inference_pose_lifter_model', 'vis_3d_pose_result',
+    'inference_interhand_3d_model', 'extract_pose_sequence'
 ]
