@@ -5,11 +5,9 @@ from functools import partial
 import numpy as np
 from mmcv.parallel import collate
 from mmcv.runner import get_dist_info
-from mmcv.utils import build_from_cfg
+from mmcv.utils import Registry, build_from_cfg
 from mmcv.utils.parrots_wrapper import _get_dataloader
 
-from .dataset_wrappers import RepeatDataset
-from .registry import DATASETS
 from .samplers import DistributedSampler
 
 if platform.system() != 'Windows':
@@ -20,6 +18,9 @@ if platform.system() != 'Windows':
     soft_limit = min(4096, hard_limit)
     resource.setrlimit(resource.RLIMIT_NOFILE, (soft_limit, hard_limit))
 
+DATASETS = Registry('dataset')
+PIPELINES = Registry('pipeline')
+
 
 def build_dataset(cfg, default_args=None):
     """Build a dataset from config dict.
@@ -32,6 +33,8 @@ def build_dataset(cfg, default_args=None):
     Returns:
         Dataset: The constructed dataset.
     """
+    from .dataset_wrappers import RepeatDataset
+
     if cfg['type'] == 'RepeatDataset':
         dataset = RepeatDataset(
             build_dataset(cfg['dataset'], default_args), cfg['times'])
