@@ -2,6 +2,7 @@ from .topdown_aic_dataset import TopDownAicDataset
 from .topdown_coco_dataset import TopDownCocoDataset
 from .topdown_coco_wholebody_dataset import TopDownCocoWholeBodyDataset
 from .topdown_crowdpose_dataset import TopDownCrowdPoseDataset
+from .topdown_h36m_dataset import TopDownH36MDataset
 from .topdown_jhmdb_dataset import TopDownJhmdbDataset
 from .topdown_mhp_dataset import TopDownMhpDataset
 from .topdown_mpii_dataset import TopDownMpiiDataset
@@ -13,5 +14,5 @@ __all__ = [
     'TopDownAicDataset', 'TopDownCocoDataset', 'TopDownCocoWholeBodyDataset',
     'TopDownCrowdPoseDataset', 'TopDownMpiiDataset', 'TopDownMpiiTrbDataset',
     'TopDownOCHumanDataset', 'TopDownPoseTrack18Dataset',
-    'TopDownJhmdbDataset', 'TopDownMhpDataset'
+    'TopDownJhmdbDataset', 'TopDownMhpDataset', 'TopDownH36MDataset'
 ]
