@@ -10,7 +10,7 @@ from poseval.evaluateAP import evaluateAP
 from xtcocotools.coco import COCO
 
 from ....core.post_processing import oks_nms, soft_oks_nms
-from ...registry import DATASETS
+from ...builder import DATASETS
 from .topdown_coco_dataset import TopDownCocoDataset
 
 
@@ -199,7 +199,7 @@ class TopDownPoseTrack18Dataset(TopDownCocoDataset):
 
             if self.use_nms:
                 nms = soft_oks_nms if self.soft_nms else oks_nms
-                keep = nms(list(img_kpts), oks_thr, sigmas=self.sigmas)
+                keep = nms(img_kpts, oks_thr, sigmas=self.sigmas)
                 valid_kpts[image_id].append(
                     [img_kpts[_keep] for _keep in keep])
             else:
