@@ -4,7 +4,7 @@ import numpy as np
 import torch.nn as nn
 from mmcv.cnn import build_conv_layer, build_norm_layer
 
-from ..registry import BACKBONES
+from ..builder import BACKBONES
 from .resnet import ResNet
 from .resnext import Bottleneck
 
