@@ -7,7 +7,7 @@ import torch.utils.checkpoint as cp
 from mmcv.cnn import ConvModule, constant_init, normal_init
 from torch.nn.modules.batchnorm import _BatchNorm
 
-from ..registry import BACKBONES
+from ..builder import BACKBONES
 from .base_backbone import BaseBackbone
 from .utils import channel_shuffle, load_checkpoint
 
