@@ -321,7 +321,7 @@ class Interhand3DHead(nn.Module):
         self.hand_type_loss = build_loss(loss_hand_type)
         self.train_cfg = {} if train_cfg is None else train_cfg
         self.test_cfg = {} if test_cfg is None else test_cfg
-        self.target_type = self.test_cfg.get('target_type', 'GaussianHeatMap')
+        self.target_type = self.test_cfg.get('target_type', 'GaussianHeatmap')
 
     def init_weights(self):
         self.left_hand_head.init_weights()
